#!/bin/bash

#set -xuve

if [ $# -ne 2 ]; then
	echo "Wrong number of arguments"
	echo "E.g.: $0 <ARCH> <EXPID>"
	exit 1
fi

ARCH=$1
EXPID=$2

case $ARCH in
	local)
		rsrc=/home/dmanubens/tmp
		error_file="err"
		out_file="out"
		;;
	turing)
		rsrc=/cfu/autosubmit
		error_file="err"
		out_file="out"
		;;
	mn)
		rsrc=/gpfs/scratch/*/*
		error_file="err"
		out_file="out"
		;;
	ithaca)
		rsrc=/scratch/cfu/*
		error_file="\.e"
		out_file="out"
		;;
	ecmwf)
		rsrc=c2a:/scratch/ms
		error_file="err"
		out_file="out"
		;;
	hector)
		rsrc=
		error_file=""
		out_file="out"
		;;
	lindgren)
		rsrc=/cfs/klemming/scratch/*/*
		out_file="out"
		;;
	jaguar)
		rsrc=
		error_file=""
		out_file="out"
		;;
	*)
		echo "!!! $ARCH is not available !!!"
		exit 1
		;;
esac

TYPE="sim"
LOG_PATH="$rsrc/$EXPID/LOG_$EXPID"
sdates=$(ls -1 ${LOG_PATH}/${EXPID}_*_${TYPE}_COMPLETED | cut -d '_' -f 3 | uniq)
echo "Name,Queue,Run,Failed,FailQueue,FailRun"
for s in $sdates; do
	mems_chunks=$(ls -1tr ${LOG_PATH}/${EXPID}_${s}_*_${TYPE}_COMPLETED | cut -d '_' -f 4-5 | uniq)
	for m_c in $mems_chunks; do
		job=${EXPID}_${s}_${m_c}_${TYPE}
		#submit_time=$(ls -1tr ${LOG_PATH}/${job}.cmd | xargs stat -c %Y)
		failed_times=$(($(ls -1tr ${LOG_PATH}/${job}*${error_file} | wc -l) -1 ))
		queued_time=$(grep "+ job_queue_time=" $(ls -1tr ${LOG_PATH}/${job}*${error_file} | tail -n 1) | cut -d '=' -f 2)
		errfile=$(ls -1tr ${LOG_PATH}/${job}*${error_file} | tail -n 1)
		errfile_stamp=$(stat -c %Y $errfile)
		run_time=$((${errfile_stamp}-$(grep "+ job_start_time=" $(ls -1tr ${LOG_PATH}/${job}*${error_file} | tail -n 1) | cut -d '=' -f 2)))
		#start_time=$(grep "Started" $(ls -1tr ${LOG_PATH}/${job}*${out_file} | tail -n 1) | cut -d" " -f 3-)
		#start_time=$(date --date="${start_time}" +%s)
		#end_time=$(grep "Results" $(ls -1tr ${LOG_PATH}/${job}*${out_file} | tail -n 1) | cut -d" " -f 4-)
		#end_time=$(date --date="${end_time}" +%s)
		#queued_time=$((${start_time}-${submit_time}))
		#run_time=$((${end_time}-${start_time}))
		fail_queued_time=0
		fail_run_time=0
		for fail_errfile in $(ls -1 ${LOG_PATH}/${job}* | grep $error_file); do
			# be careful not to pick the last err file which is currently in use which depends on platform ??????
			# cambiar aquestes linies per buscar en output file, Started, submit i Results
			# en marenostrum ok, pero en els altres??
			fail_errfile_stamp=$(stat -c %Y $fail_errfile)
			#start_time=$(grep "Started" $(ls -1tr $fail_outfile | tail -n 1) | cut -d" " -f 3-)
			#start_time=$(date --date="${start_time}" +%s)
			#end_time=$(grep "Results" $(ls -1tr $fail_outfile | tail -n 1) | cut -d" " -f 4-)
			#end_time=$(date --date="${end_time}" +%s)
			# resulta que el err es crea al final... com saber quan es el submit time de l'intent??
			# fail_queued_time=$((${fail_queued_time}+${start_time}-${fail_outfile_stamp}))
			# fail_run_time=$((${fail_run_time}+${end_time}-${start_time}))
			fail_queued_time=$((${fail_queued_time}+$(($(grep "+ job_queue_time=" $fail_errfile | tail -n 1 | cut -d '=' -f 2)))))
			fail_run_time=$((${fail_run_time}+$((${fail_errfile_stamp}-$(grep "+ job_start_time=" $fail_errfile | tail -n 1 | cut -d '=' -f 2)))))
		done
		fail_queued_time=$((${fail_queued_time}-${queued_time}))
		fail_run_time=$((${fail_run_time}-${run_time}))
		echo "$queued_time $run_time $failed_times $fail_queued_time $fail_run_time" > ${LOG_PATH}/${job}_COMPLETED
		echo "${job},${queued_time},${run_time},${failed_times},${fail_queued_time},${fail_run_time}"
	done
done
